{ config, pkgs, lib, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-config.nix
      ../../common
      ../../desktop
      ../../desktop/streaming.nix
      ../../desktop/gnome.nix
    ];

  boot.loader.grub ={
    enable = true;
    version = 2;
    efiSupport = true;
    device = "nodev";
  };
  boot.loader.efi = {
    canTouchEfiVariables = true;
    efiSysMountPoint = "/boot";
  };

  hardware.decklink.enable = true;

  networking.hostName = "nixda"; # Define your hostname.

  environment.systemPackages = with pkgs; [ blackmagicDesktopVideo blender companion ];

  networking.wg-quick.interfaces.cornbox = {
    privateKeyFile = "/etc/wireguard/cornbox.key";
    address = [ "195.39.247.67/28" "2a0f:4ac0:1337::12/64" ];
    postUp = "/run/wrappers/bin/ping -c5 195.39.247.65";
    peers = [
      {
        persistentKeepalive = 25;
        allowedIPs = [ "2a0f:4ac0:1337::/48" "195.39.247.64/27" ];
        publicKey = "8IWyiQL3wKP9CD/4UdS9b8mcbL67mkUyeSPORgEPvV0=";
        endpoint = "cornbox.hetzner.chaoswit.ch:51821";
      }
    ];
  };

  services.xserver = {
    enable = true;
    videoDrivers = [ "nvidia" ];
  };
  hardware.nvidia.modesetting.enable = true;

  boot.kernelPackages = pkgs.linuxPackages;
  boot.blacklistedKernelModules = [ "snd_blackmagic_io" ];

  users.users.stream = {
    isNormalUser = true;
    password = "hacchacc";
    extraGroups = [ "audio" "video" ];
  };

  services.pipewire.enable = true;
  services.pipewire.pulse.enable = true;
  hardware.pulseaudio.enable = lib.mkForce false;

  services.udev.extraRules = ''
    SUBSYSTEM=="input", GROUP="input", MODE="0666"
    SUBSYSTEM=="usb", ATTRS{idVendor}=="0fd9", ATTRS{idProduct}=="006?", MODE:="666", GROUP="plugdev"
    KERNEL=="hidraw", ATTRS{idVendor}=="0fd9", ATTRS{idProduct}=="006?", MODE:="666", GROUP="plugdev"
    SUBSYSTEM=="usb", ATTRS{idVendor}=="ffff", ATTRS{idProduct}=="1f4?", MODE:="666", GROUP="plugdev"
    KERNEL=="hidraw", ATTRS{idVendor}=="ffff", ATTRS{idProduct}=="1f4?", MODE:="666", GROUP="plugdev"
  '';

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "20.09"; # Did you read the comment?

}
